Please use the following to cite the NiaAML library::

    @article{pecnik2021niaaml,
        title={NiaAML: AutoML framework based on stochastic population-based nature-inspired algorithms},
        author={Pe{\v{c}}nik, Luka and Fister Jr., Iztok},
        journal={Journal of Open Source Software},
        volume={6},
        number={61},
        pages={2949},
        year={2021}
        }
